@@ -90,7 +90,11 @@ def global_options(fn):
 
 @click.group(cls=DecoratingGroup, context_settings=CONTEXT_SETTINGS)
 @global_options
-def click_cli():
+@click.pass_obj
+@click.pass_context
+def click_cli(ctx, env: Environment):
+    if ctx.invoked_subcommand != completion.name:
+        env.kubectl.download()
     pass
 
 
@@ -120,7 +124,7 @@ def fix_url(url):
 def completion(ctx, env: Environment, kubectl_arg):
     """Output shell completion code for the specified shell"""
     if not env.kubectl.exists():
-        raise Exception("kubectl not found, run any other command to download")
+        raise Exception("zkubectl: completions not yet available, run any zkubectl command to finish setting up")
 
     cmdline = ["completion"]
     cmdline.extend(kubectl_arg)
@@ -203,8 +207,6 @@ def dashboard(env: Environment):
     """Open the Kubernetes dashboard UI in the browser"""
     import threading
 
-    # first make sure kubectl was downloaded
-    env.kubectl.download()
     thread = threading.Thread(target=_open_dashboard_in_browser)
     # start short-lived background thread to allow running "kubectl proxy" in main thread
     thread.start()
@@ -236,9 +238,6 @@ def opsview(env: Environment):
     """Open the Kubernetes Operational View (kube-ops-view) in the browser"""
     import threading
 
-    # first make sure kubectl was downloaded
-    env.kubectl.download()
-
     # pre-pull the kube-ops-view image
     image_name = "hjacobs/kube-ops-view:0.10"
     subprocess.check_call(["docker", "pull", image_name])
@@ -566,7 +565,7 @@ def tunnel(env: Environment, address, target, ports):
     # the time in seconds after which the port forwarding job gets cleanup up
     job_ttl = 3600
     # the version of the socat image to use
-    socat_version = "1.7.3.3-r0"
+    socat_version = "1.7.4.1-r0"
 
     # remove any resources we created when shutting down
     @atexit.register
@@ -576,8 +575,7 @@ def tunnel(env: Environment, address, target, ports):
 
     signal.signal(signal.SIGTERM, remove_pods)
 
-    # download kubectl and refresh token
-    env.kubectl.download()
+    # refresh token
     kube_config.update_token()
 
     # generate socat container specs for each port
@@ -923,7 +921,12 @@ def check_latest_zkubectl_version():
     time_delta = datetime.datetime.now() - last_modified
     if time_delta.days < 1:
         return
-    resp = requests.get("https://pypi.org/pypi/zalando-kubectl/json")
+
+    # We don't want to keep trying if a check fails, it's fine to retry tomorrow
+    Path(f).touch()
+
+    resp = requests.get("https://pypi.org/pypi/zalando-kubectl/json", timeout=10)
+    resp.raise_for_status()
     data = resp.json()
     latest_release_version = "v" + data["info"]["version"]
     if latest_release_version != zalando_kubectl.APP_VERSION:
@@ -933,7 +936,13 @@ def check_latest_zkubectl_version():
                 zalando_kubectl.APP_VERSION, latest_release_version
             )
         )
-    Path(f).touch()
+
+
+def debug_print_exc():
+    if "ZKUBECTL_DEBUG" in os.environ:
+        import traceback
+
+        traceback.print_exc()
 
 
 def main():
@@ -954,7 +963,7 @@ def main():
             check_latest_zkubectl_version()
         # Only inform users to update zkubectl
         except Exception as e:
-            clickclick.error(e)
+            clickclick.error("Unable to check for updates: {}".format(e))
 
     try:
         # We need a dummy context to make Click happy
@@ -970,9 +979,12 @@ def main():
             kube_config.update_token()
             ctx.obj.kubectl.exec(*sys.argv[1:])
     except KeyboardInterrupt:
+        debug_print_exc()
         pass
     except BrokenPipeError:
+        debug_print_exc()
         sys.exit(141)
     except Exception as e:
+        debug_print_exc()
         clickclick.error(e)
         sys.exit(1)
