@@ -148,9 +148,19 @@ class Environment:
             exec_name="zkubectl-{}".format(APP_VERSION),
         )
 
-        stern_template = "https://github.com/wercker/stern/releases/download/{version}/stern_{os}_{arch}"
+        stern_template = (
+            "https://github.com/stern/stern/releases/download/v{version}/stern_{version}_{os}_{arch}.tar.gz"
+        )
         self.stern = ExternalBinary(
-            self, "stern", stern_template, STERN_VERSION, hashlib.sha256, STERN_SHA256, extract_none
+            self,
+            "stern",
+            stern_template,
+            STERN_VERSION,
+            hashlib.sha256,
+            STERN_SHA256,
+            extract_tgz(
+                "stern_{version}_{os}_{arch}/stern".format(version=STERN_VERSION, os=sys.platform, arch="amd64")
+            ),
         )
 
     def store_config(self):
